"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const enquirer = require("enquirer");
const fs_1 = require("fs");
const marked = require("marked");
const TerminalRenderer = require("marked-terminal");
const path_1 = require("path");
class Go extends command_1.Command {
    constructor() {
        super(...arguments);
        this.stateFile = path_1.join(__dirname, 'state');
    }
    get state() {
        if (!fs_1.existsSync(this.stateFile)) {
            return 0;
        }
        const state = fs_1.readFileSync(this.stateFile, 'utf-8');
        return parseInt(state, 10);
    }
    set state(state) {
        fs_1.writeFileSync(this.stateFile, state);
    }
    async run() {
        let prevFile;
        const choices = Go.agenda.reduce((memo, [name, file]) => {
            if (prevFile && prevFile !== file) {
                memo.push({ role: 'separator' });
            }
            memo.push(name);
            prevFile = file;
            return memo;
        }, []);
        const prompt = new enquirer.Select({
            name: Go.description,
            message: 'Pick your next exercise',
            choices: choices.slice(),
            initial: this.state
        });
        const fileName = await prompt.run();
        this.state = choices.indexOf(fileName);
        const filePath = path_1.join(Go.assetsPath, `${fileName}.md`);
        marked.setOptions({
            renderer: new TerminalRenderer({ tab: 2 })
        });
        const exercise = marked(fs_1.readFileSync(filePath, 'utf-8'));
        this.log(exercise);
    }
}
exports.default = Go;
Go.description = 'Practice Exercise';
Go.agenda = [
    ['Hello World', 'hello-world-cli-in-node.md'],
    ['Parse arguments', 'hello-world-cli-in-node.md'],
    ['Hello World with TypeScript', 'hello-world-cli-in-node.md'],
    ['Configure oclif project', 'make-it-work-with-oclif.md'],
    ['Make it Work', 'make-it-work-with-oclif.md'],
    ['List Github Issues', 'make-it-shine.md'],
    ['Assign an Issue', 'make-it-shine.md'],
    ['Notify Slack on Issues Update', 'oclif-in-depth.md'],
    ['Add Tests', 'oclif-in-depth.md'],
    ['Commands VS Plugins', 'oclif-in-depth.md'],
];
Go.assetsPath = path_1.join(__dirname, '../../assets');
